@@ -105,10 +105,10 @@ class ModelBase(object):
             (FMU)Model.set('damper.d', 1.1)
             (FMU)Model.set(['damper.d','gear.a'], [1.1, 10])
         """
-        if isinstance(variable_name, basestring):
+        if isinstance(variable_name, str):
             self._set(variable_name, value) #Scalar case
         else:
-            for i in xrange(len(variable_name)): #A list of variables
+            for i in range(len(variable_name)): #A list of variables
                 self._set(variable_name[i], value[i])
     
     def get(self, variable_name):
@@ -132,11 +132,11 @@ class ModelBase(object):
             # Returns a list of the variables
             (FMU)Model.get(['damper.d','gear.a'])
         """
-        if isinstance(variable_name, basestring):
+        if isinstance(variable_name, str):
             return self._get(variable_name) #Scalar case
         else:
             ret = []
-            for i in xrange(len(variable_name)): #A list of variables
+            for i in range(len(variable_name)): #A list of variables
                 ret += [self._get(variable_name[i])]
             return ret
     
@@ -150,12 +150,10 @@ class ModelBase(object):
             Exception if algorithm is not a subclass of 
             common.algorithm_drivers.AlgorithmBase.
         """
-        base_path = 'algorithm_drivers'
-        algdrive = __import__(base_path, globals(), locals(), [], -1)
-        AlgorithmBase = getattr(algdrive, 'AlgorithmBase')
+        from algorithm_drivers import AlgorithmBase
         
-        if isinstance(algorithm, basestring):
-            module = __import__(module, globals(), locals(), [algorithm], -1)
+        if isinstance(algorithm, str):
+            module = __import__(module, globals(), locals(), [algorithm], 0)
             algorithm = getattr(module, algorithm)
         
         if not issubclass(algorithm, AlgorithmBase):
@@ -185,12 +183,10 @@ class ModelBase(object):
             Exception if algorithm is not a subclass of 
             common.algorithm_drivers.AlgorithmBase.
         """
-        base_path = 'algorithm_drivers'
-        algdrive = __import__(base_path, globals(), locals(), [], -1)
-        AlgorithmBase = getattr(algdrive, 'AlgorithmBase')
+        from algorithm_drivers import AlgorithmBase
         
-        if isinstance(algorithm, basestring):
-            module = __import__(module, globals(), locals(), [algorithm], -1)
+        if isinstance(algorithm, str):
+            module = __import__(module, globals(), locals(), [algorithm], 0)
             algorithm = getattr(module, algorithm)
         
         if not issubclass(algorithm, AlgorithmBase):
@@ -210,7 +206,7 @@ class ModelBase(object):
         Help method. Gets the options class for the algorithm specified in 
         'algorithm'.
         """
-        module = __import__(module, globals(), locals(), [algorithm], -1)
+        module = __import__(module, globals(), locals(), [algorithm], 0)
         algorithm = getattr(module, algorithm)
         
         return algorithm.get_default_options()
